@@ -25,7 +25,7 @@ use strict;
 use Getopt::Long qw(:config pass_through no_auto_abbrev);
 
 my $app_name     = 'colordiff';
-my $version      = '1.0.15';
+my $version      = '1.0.16';
 my $author       = 'Dave Ewart';
 my $author_email = 'davee@sungate.co.uk';
 my $app_www      = 'http://www.colordiff.org/';
@@ -66,6 +66,12 @@ my $HOME   = $ENV{HOME};
 my $etcdir = '/etc';
 my ($setting, $value);
 my @config_files = ("$etcdir/colordiffrc");
+if (defined $ENV{XDG_CONFIG_HOME} && $ENV{XDG_CONFIG_HOME} ne '') {
+    push (@config_files, "$ENV{XDG_CONFIG_HOME}/colordiff/colordiffrc")
+}
+elsif (defined $ENV{HOME}) {
+    push (@config_files, "$ENV{HOME}/.config/colordiff/colordiffrc")
+}
 push (@config_files, "$ENV{HOME}/.colordiffrc") if (defined $ENV{HOME});
 my $config_file;
 my $diff_type = 'unknown';
@@ -166,9 +172,13 @@ GetOptions(
     "fakeexitcode" => \$enable_fakeexitcode,
     "difftype=s" => \$specified_difftype,
     "color=s" => \$color_mode
-    # TODO - check that specified type is valid, issue warning if not
 );
 
+$_ = $specified_difftype;
+if (defined $_ and not /^diff[cuy]?|(deb|w)diff$/) {
+    print STDERR "Invalid --difftype value\n";
+}
+
 if (defined $enable_verifymode) {
     # When in verify mode, to ensure consistent output we don't source
     # any external config files, so we use built-in defaults
@@ -308,16 +318,21 @@ if ($operating_methodology == 1) {
 # Input stream has been read - need to examine it
 # to determine type of diff we have.
 
-my $lastline;
+# $lastline is false if the input is EOF. If true, then either more data is
+# available, or the last read succeeded (and the next read may return EOF).
+# Initially assume that the input is not EOF (for obvious reasons).
+my $lastline = 1;
 my $record;
 
 if (defined $specified_difftype) {
     $diff_type = $specified_difftype;
     # diffy needs at least one line to look at
-    if ($diff_type eq 'diffy' and ($_ = <$inputhandle>)) {
-        push @inputstream, $_;
+    if ($diff_type eq 'diffy') {
+        if (defined($_ = <$inputhandle>)) {
+            push @inputstream, $_;
+        }
+        $lastline = $_;
     }
-    $lastline = $_;
 }
 else {
     # Detect diff type, diffy is permitted
